// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIDLETIME_VERSION_H
#define KIDLETIME_VERSION_H

#define KIDLETIME_VERSION_STRING "5.115.0"
#define KIDLETIME_VERSION_MAJOR 5
#define KIDLETIME_VERSION_MINOR 115
#define KIDLETIME_VERSION_PATCH 0
#define KIDLETIME_VERSION ((5<<16)|(115<<8)|(0))

#endif
